package com.zanxiang.game.module.manage.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.zanxiang.game.module.manage.pojo.dto.GameAppletDTO;
import com.zanxiang.game.module.manage.pojo.params.GameAccountUpdateParam;
import com.zanxiang.game.module.manage.pojo.vo.GameAccountVO;
import com.zanxiang.game.module.mybatis.entity.GameApplet;

/**
 * @author : lingfeng
 * @time : 2022-07-08
 * @description : 微信小游戏(小程序)
 */
public interface IGameAppletService extends IService<GameApplet> {

    /**
     * 通过游戏id
     *
     * @param gameId 游戏id
     * @return {@link GameAppletDTO}
     */
    GameAppletDTO getByGameId(Long gameId);

    /**
     * 获取账号信息配置
     *
     * @param id : 游戏id
     * @return {@link GameAccountVO}
     */
    GameAccountVO getGameAccount(Long id);

    /**
     * 获取账号信息配置
     *
     * @param param : 更新参数
     * @return {@link Boolean}
     */
    Boolean gameAccountAddOrUpdate(GameAccountUpdateParam param);

    /**
     * 获取游戏小程序二维码
     *
     * @param gameId : 游戏id
     * @return {@link String}
     */
    String getQrCodByGameId(Long gameId);

    /**
     * 获取小游戏二维码
     *
     * @param appId       应用程序id
     * @param appSecret   应用程序秘密
     * @param ossFileName oss文件名
     * @return {@link String}
     */
    String getQrCode(String appId, String appSecret, String ossFileName);
}
