package com.zanxiang.game.module.sdk.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.game.module.mybatis.entity.GameExt;
import com.zanxiang.game.module.mybatis.mapper.GameExtMapper;
import com.zanxiang.game.module.sdk.constant.RedisKeyConstant;
import com.zanxiang.game.module.sdk.enums.ExpireTimeEnum;
import com.zanxiang.game.module.sdk.service.IGameExtService;
import com.zanxiang.game.module.sdk.util.RedisUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author : lingfeng
 * @time : 2022-09-23
 * @description : 游戏密钥
 */
@Slf4j
@Service
public class GameExtServiceImpl extends ServiceImpl<GameExtMapper, GameExt> implements IGameExtService {

    @Autowired
    private RedisUtil<GameExt> redisUtil;

    @Override
    public GameExt getByGameId(Long gameId) {
        //查询缓存
        GameExt gameExt = redisUtil.getCache(this.getGameKey(String.valueOf(gameId)));
        if (gameExt != null) {
            return gameExt;
        }
        gameExt = this.getOne(new LambdaQueryWrapper<GameExt>().eq(GameExt::getGameId, gameId));
        if (gameExt != null) {
            redisUtil.setCache(this.getGameKey(String.valueOf(gameId)), gameExt, ExpireTimeEnum.ONE_DAY.getTime());
        }
        return gameExt;
    }

    @Override
    public GameExt getByGameAppId(String appId) {
        //查询缓存
        GameExt gameExt = redisUtil.getCache(this.getGameKey(appId));
        if (gameExt != null) {
            return gameExt;
        }
        gameExt = this.getOne(new LambdaQueryWrapper<GameExt>().eq(GameExt::getAppId, appId));
        if (gameExt != null) {
            redisUtil.setCache(this.getGameKey(appId), gameExt, ExpireTimeEnum.ONE_DAY.getTime());
        }
        return gameExt;
    }

    private String getGameKey(String key) {
        return RedisKeyConstant.GAME_SECRET_KEY + "_" + key;
    }
}
